@@ -1,7 +1,7 @@
 // ==========================================================================
 //                              casbar
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -165,8 +165,8 @@ copyNextWindowMatchesAndReads(TFragmentStore &fragmentStore,
     --itG;
 
     // We will use minCoord/maxCoord to store the temporarily minimal and maximal coordinates in the window.
-    int minCoord = maxValue<int>();
-    int maxCoord = minValue<int>();
+    int minCoord = std::numeric_limits<int>::max();
+    int maxCoord = std::numeric_limits<int>::min();
     //CharString str = "discBef";
     //_dumpMatches(fragmentStore, str);
 
@@ -192,9 +192,9 @@ copyNextWindowMatchesAndReads(TFragmentStore &fragmentStore,
     }
 
     // Write minimal and maximal coordinate from reads in this window to options.minCoord/options.maxCoord.
-    if (minCoord != maxValue<int>())
+    if (minCoord != std::numeric_limits<int>::max())
         options.minCoord = minCoord;
-    if (maxCoord != minValue<int>())
+    if (maxCoord != std::numeric_limits<int>::min())
         options.maxCoord = maxCoord;
 
     if(options._debugLevel > 1)
@@ -625,7 +625,7 @@ detectSNPsForContig(seqan::VcfFileOut & vcfFileOut,
     TReadStore tmpRs;
     TReadSeqStore tmpReads;     // Something went wrong when keeping all reads of contig, so keep it like that for the moment
     TSetContigAnchorGaps tmpSetContigAnchorGaps;
-    options.minCoord = MaxValue<unsigned>::VALUE;
+    options.minCoord = std::numeric_limits<unsigned>::max();
     options.maxCoord = 0;
 
     // snp calling is done for all positions between windowBegin and windowEnd
