@@ -187,7 +187,7 @@ _stellarOnAll(StringSet<TSequence> & databases,
     std::cout << std::endl;
 
     // file output
-    if (options.disableThresh != seqan::maxValue<unsigned>())
+    if (options.disableThresh != std::numeric_limits<unsigned>::max())
     {
         if (!_outputMatches(matches, queries, queryIDs, databases, options.verbose,
                             options.outputFile, options.outputFormat, options.disabledQueriesFile))
@@ -569,7 +569,7 @@ void _setParser(ArgumentParser & parser)
     setDefaultValue(parser, "o", "stellar.gff");
     addOption(parser, ArgParseOption("od", "outDisabled",
                                      "Name of output file for disabled query sequences.", ArgParseArgument::OUTPUT_FILE));
-    setValidValues(parser, "outDisabled", "fa fasta");
+    setValidValues(parser, "outDisabled", seqan::SeqFileOut::getFileExtensions());
     setDefaultValue(parser, "od", "stellar.disabled.fasta");
     addOption(parser, ArgParseOption("t", "no-rt", "Suppress printing running time."));
     hideOption(parser, "t");
@@ -637,7 +637,7 @@ int mainWithOptions(TOptions & options, String<TAlphabet>)
     }
     file.close();
 
-    if (options.disableThresh != seqan::maxValue<unsigned>())
+    if (options.disableThresh != std::numeric_limits<unsigned>::max())
     {
         std::ofstream daFile;
         daFile.open(toCString(options.disabledQueriesFile));
