@@ -7,7 +7,7 @@ using namespace seqan;
 
 int main()
 {
-    std::string inPath = std::string(SEQAN_PATH_TO_ROOT()) + "/tests/blast/plus_comments_defaults.m9";
+    std::string inPath = getAbsolutePath("/tests/blast/plus_comments_defaults.m9");
 
     std::ifstream fin(toCString(inPath), std::ios_base::in | std::ios_base::binary);
     auto fit = directionIterator(fin, Input());
@@ -46,4 +46,4 @@ int main()
     std::cerr << "Demo not run, because of a bug in Microsoft Visual Studio 2015.\n";
     return 0;
 }
-#endif
\ No newline at end of file
+#endif
