@@ -10,8 +10,7 @@ using namespace seqan;
 int main()
 {
     // Build path to background FASTA file.
-    CharString bgPath = SEQAN_PATH_TO_ROOT();
-    append(bgPath, "/demos/statistics/background.fa");
+    CharString bgPath = getAbsolutePath("/demos/statistics/background.fa");
 
     // Read the background from a file into X.
     StringSet<DnaString> X;
