@@ -1,5 +1,3 @@
-// Generalize the computeLocalScore function in you file.
-
 #include <iostream>
 #include <seqan/file.h>
 #include <seqan/sequence.h>
@@ -39,7 +37,7 @@ void print(String<int> const & text)
 
 int main()
 {
-    String<char> text = "This is an awesome tutorial to get to now SeqAn!";
+    String<char> text = "This is an awesome tutorial to get to know SeqAn!";
     String<char> pattern = "tutorial";
     String<int> score = computeScore(text, pattern);
     print(score);
