@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -549,7 +549,7 @@ inline bool tagSelectIntersect(TagSelector<TOutTagList> & outTagList, Tag<TagSpe
 {
     typedef typename TOutTagList::Type TFormat;
 
-    if (IsSameType<Tag<TagSpec>, TFormat>::VALUE)
+    SEQAN_IF_CONSTEXPR (IsSameType<Tag<TagSpec>, TFormat>::VALUE)
     {
         outTagList.tagId = LENGTH<TOutTagList>::VALUE - 1;
         return true;
