@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -652,8 +652,7 @@ template <typename T>
 inline T
 _getInfinity()
 {
-    T * _tag = 0;
-    return supremumValueImpl(_tag);
+    return std::numeric_limits<T>::max();
 }
 
 //////////////////////////////////////////////////////////////////////////////
