@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -284,7 +284,7 @@ template <typename TPrefix>
 inline unsigned
 getScore(PrefixAligner_<TPrefix, HammingDistance> const & me, bool atEnd)
 {
-    return atEnd ? me.errors : MaxValue<unsigned>::VALUE;
+    return atEnd ? me.errors : std::numeric_limits<unsigned>::max();
 }
 
 template <typename TPrefix>
