@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -582,11 +582,10 @@ struct CreateArrayStringExpand_
                 _deallocateStorage(target, buf, old_target_capacity);
             }
         }
-        assignValue(begin(target, Standard()), 0); //set target length to 0
+        assign(*begin(target, Standard()), 0); //set target length to 0
         assign(begin(target, Standard()), source, Insist());
         typedef typename Iterator<TTarget>::Type TTargetIterator;
         _setEnd(target, TTargetIterator( begin(target) + source_length));
-
     }
 
     template <typename TTarget, typename TSource, typename TLimit>
