@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -813,20 +813,17 @@ public:
 struct AiocbWrapper :
     public aiocb
 {
-    AiocbWrapper()
-    {}
+    AiocbWrapper() = default;
+    AiocbWrapper(AiocbWrapper &&) = default;
 
     AiocbWrapper(AiocbWrapper & other, Move) :
         aiocb(other)
     {}
 
-    AiocbWrapper(AiocbWrapper && other) :
-        aiocb(other)
-    {}
-
+    AiocbWrapper & operator=(AiocbWrapper &&) = default;
 private:
-    AiocbWrapper(AiocbWrapper const &)
-    {}
+    AiocbWrapper(AiocbWrapper const &) = delete;
+    AiocbWrapper & operator=(AiocbWrapper const &) = delete;
 };
 
 template <>
