@@ -1,7 +1,7 @@
 // ==========================================================================
 //                       test_alignment_dp_traceback.h
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -57,28 +57,27 @@ SEQAN_DEFINE_TEST(test_align2_traceback_affine)
 
     resize(traceMatrix);
 
-    value(traceMatrix, 0, 0) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 0) = +TraceBitMap_<>::VERTICAL_OPEN | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 2, 0) = +TraceBitMap_<>::VERTICAL | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 3, 0) = +TraceBitMap_<>::VERTICAL | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 0, 0) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 0) = TraceBitMap_<>::VERTICAL_OPEN | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 2, 0) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 3, 0) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
 
-    value(traceMatrix, 0, 1) = +TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 1, 1) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 2, 1) = +TraceBitMap_<>::HORIZONTAL_OPEN | +TraceBitMap_<>::DIAGONAL | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX | +TraceBitMap_<>::VERTICAL_OPEN;
-    value(traceMatrix, 3, 1) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 0, 1) = TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 1, 1) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 2, 1) = TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::DIAGONAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX | TraceBitMap_<>::VERTICAL_OPEN;
+    value(traceMatrix, 3, 1) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
 
-    value(traceMatrix, 0, 2) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 1, 2) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 2, 2) = +TraceBitMap_<>::VERTICAL_OPEN | +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 3, 2) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 0, 2) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 1, 2) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 2, 2) = TraceBitMap_<>::VERTICAL_OPEN | TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 3, 2) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
 
-    value(traceMatrix, 0, 3) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 1, 3) = +TraceBitMap_<>::HORIZONTAL_OPEN | +TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 2, 3) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 3, 3) = +TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 0, 3) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 1, 3) = TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 2, 3) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 3, 3) = TraceBitMap_<>::DIAGONAL;
 
-    TDPTraceNavigator navigator;
-    _init(navigator, traceMatrix, DPBandConfig<BandOff>());
+    TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOff>()};
 
     DnaString str0 = "ACG";
     DnaString str1 = "ACG";
@@ -87,55 +86,55 @@ SEQAN_DEFINE_TEST(test_align2_traceback_affine)
     dpScout._maxHostPosition = 15;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
     SEQAN_ASSERT_EQ(length(target), 1u);
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(0, 0, 3, +TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(0, 0, 3, TraceBitMap_<>::DIAGONAL));
 
     clear(target);
     dpScout._maxHostPosition = 14;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
     SEQAN_ASSERT_EQ(length(target), 3u);
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 2, 1, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 2, 3, +TraceBitMap_<>::HORIZONTAL));
-    SEQAN_ASSERT_EQ(target[2], TTraceSegment(0, 0, 2, +TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 2, 1, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 2, 3, TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[2], TTraceSegment(0, 0, 2, TraceBitMap_<>::VERTICAL));
 
     clear(target);
     dpScout._maxHostPosition = 13;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
     SEQAN_ASSERT_EQ(length(target), 4u);
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 1, 2, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(2, 1, 1, +TraceBitMap_<>::HORIZONTAL));
-    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 0, 1, +TraceBitMap_<>::DIAGONAL));
-    SEQAN_ASSERT_EQ(target[3], TTraceSegment(0, 0, 1, +TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 1, 2, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(2, 1, 1, TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 0, 1, TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[3], TTraceSegment(0, 0, 1, TraceBitMap_<>::HORIZONTAL));
 
     clear(target);
     dpScout._maxHostPosition = 12;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
     SEQAN_ASSERT_EQ(length(target), 2u);
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 0, 3, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 3, +TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 0, 3, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 3, TraceBitMap_<>::HORIZONTAL));
 
     clear(target);
     dpScout._maxHostPosition = 11;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
     SEQAN_ASSERT_EQ(length(target), 4u);
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 3, 1, +TraceBitMap_<>::HORIZONTAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(2, 1, 2, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 0, 1, +TraceBitMap_<>::DIAGONAL));
-    SEQAN_ASSERT_EQ(target[3], TTraceSegment(0, 0, 1, +TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 3, 1, TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(2, 1, 2, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 0, 1, TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[3], TTraceSegment(0, 0, 1, TraceBitMap_<>::HORIZONTAL));
 
     clear(target);
     dpScout._maxHostPosition = 7;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
     SEQAN_ASSERT_EQ(length(target), 3u);
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(1, 3, 2, +TraceBitMap_<>::HORIZONTAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(1, 1, 2, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[2], TTraceSegment(0, 0, 1, +TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(1, 3, 2, TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(1, 1, 2, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[2], TTraceSegment(0, 0, 1, TraceBitMap_<>::DIAGONAL));
 
     clear(target);
     dpScout._maxHostPosition = 3;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
     SEQAN_ASSERT_EQ(length(target), 2u);
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(0, 3, 3, +TraceBitMap_<>::HORIZONTAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 3, +TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(0, 3, 3, TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 3, TraceBitMap_<>::VERTICAL));
 }
 
 SEQAN_DEFINE_TEST(test_align2_traceback_linear_unbanded_alignment)
@@ -157,28 +156,27 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_unbanded_alignment)
 
     resize(traceMatrix);
 
-    value(traceMatrix, 0, 0) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 0) = +TraceBitMap_<>::VERTICAL;
-    value(traceMatrix, 2, 0) = +TraceBitMap_<>::VERTICAL;
-    value(traceMatrix, 3, 0) = +TraceBitMap_<>::VERTICAL;
+    value(traceMatrix, 0, 0) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 0) = TraceBitMap_<>::VERTICAL;
+    value(traceMatrix, 2, 0) = TraceBitMap_<>::VERTICAL;
+    value(traceMatrix, 3, 0) = TraceBitMap_<>::VERTICAL;
 
-    value(traceMatrix, 0, 1) = +TraceBitMap_<>::HORIZONTAL;
-    value(traceMatrix, 1, 1) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 2, 1) = +TraceBitMap_<>::HORIZONTAL | +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 3, 1) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 1) = TraceBitMap_<>::HORIZONTAL;
+    value(traceMatrix, 1, 1) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 2, 1) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 3, 1) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 2) = +TraceBitMap_<>::HORIZONTAL;
-    value(traceMatrix, 1, 2) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 2, 2) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 3, 2) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 2) = TraceBitMap_<>::HORIZONTAL;
+    value(traceMatrix, 1, 2) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 2, 2) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 3, 2) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 3) = +TraceBitMap_<>::HORIZONTAL;
-    value(traceMatrix, 1, 3) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 2, 3) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 3, 3) = +TraceBitMap_<>::DIAGONAL | +TraceBitMap_<>::VERTICAL  | +TraceBitMap_<>::HORIZONTAL;
+    value(traceMatrix, 0, 3) = TraceBitMap_<>::HORIZONTAL;
+    value(traceMatrix, 1, 3) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 2, 3) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 3, 3) = TraceBitMap_<>::DIAGONAL | TraceBitMap_<>::VERTICAL  | TraceBitMap_<>::HORIZONTAL;
 
-    TDPTraceNavigator navigator;
-    _init(navigator, traceMatrix, DPBandConfig<BandOff>());
+    TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOff>{}};
 
     DnaString str0 = "ACG";
     DnaString str1 = "ACG";
@@ -187,10 +185,10 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_unbanded_alignment)
     dpScout._maxHostPosition = 15;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
 
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 2, 1, +TraceBitMap_<>::DIAGONAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(1, 2, 1, +TraceBitMap_<>::HORIZONTAL));
-    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 1, 1, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[3], TTraceSegment(0, 0, 1, +TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 2, 1, TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(1, 2, 1, TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 1, 1, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[3], TTraceSegment(0, 0, 1, TraceBitMap_<>::DIAGONAL));
 }
 
 SEQAN_DEFINE_TEST(test_align2_traceback_linear_normal_banded_alignment)
@@ -202,7 +200,7 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_normal_banded_alignment)
     typedef typename TraceBitMap_<>::Type TTraceValue;
     typedef DPMatrix_<TTraceValue, FullDPMatrix> TTraceMatrix;
 
-    typedef DPMatrixNavigator_<TTraceMatrix, DPTraceMatrix<TracebackOn<> >, NavigateColumnWise> TDPTraceNavigator;
+    typedef DPMatrixNavigator_<TTraceMatrix, DPTraceMatrix<TracebackOn<> >, NavigateColumnWiseBanded> TDPTraceNavigator;
 
     String<TTraceSegment> target;
     TTraceMatrix traceMatrix;
@@ -212,29 +210,28 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_normal_banded_alignment)
 
     resize(traceMatrix);
 
-    value(traceMatrix, 0, 0) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 0) = +TraceBitMap_<>::VERTICAL;
-    value(traceMatrix, 2, 0) = +TraceBitMap_<>::VERTICAL;
+    value(traceMatrix, 0, 0) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 0) = TraceBitMap_<>::VERTICAL;
+    value(traceMatrix, 2, 0) = TraceBitMap_<>::VERTICAL;
 
-    value(traceMatrix, 0, 1) = +TraceBitMap_<>::HORIZONTAL;
-    value(traceMatrix, 1, 1) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 2, 1) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 0, 1) = TraceBitMap_<>::HORIZONTAL;
+    value(traceMatrix, 1, 1) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 2, 1) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
 
-    value(traceMatrix, 0, 2) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 2) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 2, 2) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 2) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 2) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 2, 2) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 3) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 1, 3) = +TraceBitMap_<>::VERTICAL | +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 2, 3) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 3) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 1, 3) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 2, 3) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 4) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 4) = +TraceBitMap_<>::DIAGONAL | +TraceBitMap_<>::VERTICAL  | +TraceBitMap_<>::HORIZONTAL;
-    value(traceMatrix, 2, 4) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 4) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 4) = TraceBitMap_<>::DIAGONAL | TraceBitMap_<>::VERTICAL  | TraceBitMap_<>::HORIZONTAL;
+    value(traceMatrix, 2, 4) = TraceBitMap_<>::NONE;
 
 
-    TDPTraceNavigator navigator;
-    _init(navigator, traceMatrix, DPBandConfig<BandOn>(-1, 1));
+    TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOn>{-1, 1}};
 
     DnaString str0 = "ACGT";
     DnaString str1 = "ACGT";
@@ -243,11 +240,11 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_normal_banded_alignment)
     dpScout._maxHostPosition = 13;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOn>(-1, 1), TDPProfile());
 
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 3, 1, +TraceBitMap_<>::DIAGONAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(3, 2, 1, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 2, 2, +TraceBitMap_<>::HORIZONTAL));
-    SEQAN_ASSERT_EQ(target[3], TTraceSegment(1, 1, 1, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[4], TTraceSegment(0, 0, 1, +TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 3, 1, TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(3, 2, 1, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 2, 2, TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[3], TTraceSegment(1, 1, 1, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[4], TTraceSegment(0, 0, 1, TraceBitMap_<>::DIAGONAL));
 }
 
 SEQAN_DEFINE_TEST(test_align2_traceback_linear_wide_banded_alignment)
@@ -259,7 +256,7 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_wide_banded_alignment)
     typedef typename TraceBitMap_<>::Type TTraceValue;
     typedef DPMatrix_<TTraceValue, FullDPMatrix> TTraceMatrix;
 
-    typedef DPMatrixNavigator_<TTraceMatrix, DPTraceMatrix<TracebackOn<> >, NavigateColumnWise> TDPTraceNavigator;
+    typedef DPMatrixNavigator_<TTraceMatrix, DPTraceMatrix<TracebackOn<> >, NavigateColumnWiseBanded> TDPTraceNavigator;
 
     String<TTraceSegment> target;
     TTraceMatrix traceMatrix;
@@ -269,64 +266,63 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_wide_banded_alignment)
 
     resize(traceMatrix);
 
-    value(traceMatrix, 0, 0) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 0) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 2, 0) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 3, 0) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 4, 0) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 5, 0) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 6, 0) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 0, 0) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 0) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 2, 0) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 3, 0) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 4, 0) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 5, 0) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 6, 0) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
 
-    value(traceMatrix, 0, 1) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 1) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 2, 1) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 3, 1) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 4, 1) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 5, 1) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 6, 1) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 1) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 1) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 2, 1) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 3, 1) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 4, 1) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 5, 1) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 6, 1) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 2) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 1, 2) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 2, 2) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 3, 2) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 4, 2) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 5, 2) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 6, 2) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 2) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 1, 2) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 2, 2) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 3, 2) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 4, 2) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 5, 2) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 6, 2) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 3) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 3) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 2, 3) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 3, 3) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 4, 3) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 5, 3) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 6, 3) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 3) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 3) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 2, 3) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 3, 3) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 4, 3) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 5, 3) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 6, 3) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 4) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 4) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 2, 4) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 3, 4) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 4, 4) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 5, 4) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 6, 4) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 4) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 4) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 2, 4) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 3, 4) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 4, 4) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 5, 4) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 6, 4) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 5) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 5) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 2, 5) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 3, 5) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 4, 5) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 5, 5) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 6, 5) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 5) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 5) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 2, 5) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 3, 5) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 4, 5) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 5, 5) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 6, 5) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 6) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 6) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 2, 6) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 3, 6) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 4, 6) = +TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 5, 6) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 6, 6) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 6) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 6) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 2, 6) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 3, 6) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 4, 6) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 5, 6) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 6, 6) = TraceBitMap_<>::NONE;
 
-    TDPTraceNavigator navigator;
-    _init(navigator, traceMatrix, DPBandConfig<BandOn>(-4, 4));
+    TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOn>{-4, 4}};
 
     DnaString str0 = "ACGTAC";
     DnaString str1 = "ACGTAC";
@@ -335,10 +331,10 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_wide_banded_alignment)
     dpScout._maxHostPosition = 46;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOn>(-4, 4), TDPProfile());
 
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(6, 3, 3, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(1, 3, 5, +TraceBitMap_<>::HORIZONTAL));
-    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 1, 2, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[3], TTraceSegment(0, 0, 1, +TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(6, 3, 3, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(1, 3, 5, TraceBitMap_<>::HORIZONTAL));
+    SEQAN_ASSERT_EQ(target[2], TTraceSegment(1, 1, 2, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[3], TTraceSegment(0, 0, 1, TraceBitMap_<>::DIAGONAL));
 }
 
 SEQAN_DEFINE_TEST(test_align2_traceback_linear_small_banded_alignment)
@@ -350,7 +346,7 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_small_banded_alignment)
     typedef typename TraceBitMap_<>::Type TTraceValue;
     typedef DPMatrix_<TTraceValue, FullDPMatrix> TTraceMatrix;
 
-    typedef DPMatrixNavigator_<TTraceMatrix, DPTraceMatrix<TracebackOn<> >, NavigateColumnWise> TDPTraceNavigator;
+    typedef DPMatrixNavigator_<TTraceMatrix, DPTraceMatrix<TracebackOn<> >, NavigateColumnWiseBanded> TDPTraceNavigator;
 
     String<TTraceSegment> target;
     TTraceMatrix traceMatrix;
@@ -360,16 +356,15 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_small_banded_alignment)
 
     resize(traceMatrix);
 
-    value(traceMatrix, 0, 0) = +TraceBitMap_<>::NONE;
+    value(traceMatrix, 0, 0) = TraceBitMap_<>::NONE;
 
-    value(traceMatrix, 0, 1) = +TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 0, 1) = TraceBitMap_<>::DIAGONAL;
 
-    value(traceMatrix, 0, 2) = +TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 0, 2) = TraceBitMap_<>::DIAGONAL;
 
-    value(traceMatrix, 0, 3) = +TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 0, 3) = TraceBitMap_<>::DIAGONAL;
 
-    TDPTraceNavigator navigator;
-    _init(navigator, traceMatrix, DPBandConfig<BandOn>(0, 0));
+    TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOn>{0, 0}};
 
     DnaString str0 = "ACG";
     DnaString str1 = "ACG";
@@ -378,7 +373,7 @@ SEQAN_DEFINE_TEST(test_align2_traceback_linear_small_banded_alignment)
     dpScout._maxHostPosition = 3;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOn>(0, 0), TDPProfile());
 
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(0, 0, 3, +TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(0, 0, 3, TraceBitMap_<>::DIAGONAL));
 }
 
 SEQAN_DEFINE_TEST(test_align2_traceback_gaps_left_linear_gaps)
@@ -400,24 +395,23 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_left_linear_gaps)
 
     resize(traceMatrix);
 
-    value(traceMatrix, 0, 0) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 0) = +TraceBitMap_<>::VERTICAL_OPEN | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 2, 0) = +TraceBitMap_<>::VERTICAL;
-    value(traceMatrix, 3, 0) = +TraceBitMap_<>::VERTICAL;
+    value(traceMatrix, 0, 0) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 0) = TraceBitMap_<>::VERTICAL_OPEN | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 2, 0) = TraceBitMap_<>::VERTICAL;
+    value(traceMatrix, 3, 0) = TraceBitMap_<>::VERTICAL;
 
-    value(traceMatrix, 0, 1) = +TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 1, 1) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 2, 1) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 3, 1) = +TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::HORIZONTAL;
+    value(traceMatrix, 0, 1) = TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 1, 1) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 2, 1) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 3, 1) = TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::HORIZONTAL;
 
-    value(traceMatrix, 0, 2) = +TraceBitMap_<>::HORIZONTAL;
-    value(traceMatrix, 1, 2) = +TraceBitMap_<>::VERTICAL_OPEN | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 2, 2) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 3, 2) = +TraceBitMap_<>::VERTICAL | +TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 0, 2) = TraceBitMap_<>::HORIZONTAL;
+    value(traceMatrix, 1, 2) = TraceBitMap_<>::VERTICAL_OPEN | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 2, 2) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 3, 2) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::DIAGONAL;
 
 
-    TDPTraceNavigator navigator;
-    _init(navigator, traceMatrix, DPBandConfig<BandOff>());
+    TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOff>()};
 
     DnaString str0 = "AC";
     DnaString str1 = "CCC";
@@ -426,8 +420,8 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_left_linear_gaps)
     dpScout._maxHostPosition = 11;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
 
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(0, 1, 2, +TraceBitMap_<>::DIAGONAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 1, +TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(0, 1, 2, TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 1, TraceBitMap_<>::VERTICAL));
 }
 
 SEQAN_DEFINE_TEST(test_align2_traceback_gaps_right_linear_gaps)
@@ -449,24 +443,23 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_right_linear_gaps)
 
     resize(traceMatrix);
 
-    value(traceMatrix, 0, 0) = +TraceBitMap_<>::NONE;
-    value(traceMatrix, 1, 0) = +TraceBitMap_<>::VERTICAL_OPEN | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 2, 0) = +TraceBitMap_<>::VERTICAL | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 3, 0) = +TraceBitMap_<>::VERTICAL | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 0, 0) = TraceBitMap_<>::NONE;
+    value(traceMatrix, 1, 0) = TraceBitMap_<>::VERTICAL_OPEN | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 2, 0) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 3, 0) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
 
-    value(traceMatrix, 0, 1) = +TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 1, 1) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 2, 1) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 3, 1) = +TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 0, 1) = TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 1, 1) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 2, 1) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 3, 1) = TraceBitMap_<>::HORIZONTAL_OPEN | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
 
-    value(traceMatrix, 0, 2) = +TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
-    value(traceMatrix, 1, 2) = +TraceBitMap_<>::VERTICAL_OPEN | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
-    value(traceMatrix, 2, 2) = +TraceBitMap_<>::DIAGONAL;
-    value(traceMatrix, 3, 2) = +TraceBitMap_<>::VERTICAL | +TraceBitMap_<>::DIAGONAL | +TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 0, 2) = TraceBitMap_<>::HORIZONTAL | TraceBitMap_<>::MAX_FROM_HORIZONTAL_MATRIX;
+    value(traceMatrix, 1, 2) = TraceBitMap_<>::VERTICAL_OPEN | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
+    value(traceMatrix, 2, 2) = TraceBitMap_<>::DIAGONAL;
+    value(traceMatrix, 3, 2) = TraceBitMap_<>::VERTICAL | TraceBitMap_<>::DIAGONAL | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX;
 
 
-    TDPTraceNavigator navigator;
-    _init(navigator, traceMatrix, DPBandConfig<BandOff>());
+    TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOff>()};
 
     DnaString str0 = "AC";
     DnaString str1 = "CCC";
@@ -475,8 +468,8 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_right_linear_gaps)
     dpScout._maxHostPosition = 11;
     _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
 
-    SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 2, 1, +TraceBitMap_<>::VERTICAL));
-    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 2, +TraceBitMap_<>::DIAGONAL));
+    SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 2, 1, TraceBitMap_<>::VERTICAL));
+    SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 2, TraceBitMap_<>::DIAGONAL));
 }
 
 SEQAN_DEFINE_TEST(test_align2_traceback_gaps_left_affine_gaps)
@@ -516,8 +509,7 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_left_affine_gaps)
         value(traceMatrix, 3, 2) = TraceBitMap_<>::VERTICAL_OPEN | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX | TraceBitMap_<>::DIAGONAL;
 
 
-        TDPTraceNavigator navigator;
-        _init(navigator, traceMatrix, DPBandConfig<BandOff>());
+        TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOff>()};
 
         DnaString str0 = "AC";
         DnaString str1 = "CCC";
@@ -527,8 +519,8 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_left_affine_gaps)
         _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
 
         // TODO(rmaerker): This is disabled by default for the affine gap costs.
-        SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 2, 1, +TraceBitMap_<>::VERTICAL));
-        SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 2, +TraceBitMap_<>::DIAGONAL));
+        SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 2, 1, TraceBitMap_<>::VERTICAL));
+        SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 2, TraceBitMap_<>::DIAGONAL));
     }
 
     {   // Tests inner gaps.
@@ -563,8 +555,7 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_left_affine_gaps)
         value(traceMatrix, 2, 4) = TraceBitMap_<>::NONE;
         value(traceMatrix, 3, 4) = TraceBitMap_<>::DIAGONAL;
 
-        TDPTraceNavigator navigator;
-        _init(navigator, traceMatrix, DPBandConfig<BandOff>());
+        TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOff>()};
 
         DnaString str0 = "ACCA";
         DnaString str1 = "ACA";
@@ -574,9 +565,9 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_left_affine_gaps)
         _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
 
         // TODO(rmaerker): This is disabled by default for the affine gap costs.
-        SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 1, 2, +TraceBitMap_<>::DIAGONAL));
-        SEQAN_ASSERT_EQ(target[1], TTraceSegment(1, 1, 1, +TraceBitMap_<>::HORIZONTAL));
-        SEQAN_ASSERT_EQ(target[2], TTraceSegment(0, 0, 1, +TraceBitMap_<>::DIAGONAL));
+        SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 1, 2, TraceBitMap_<>::DIAGONAL));
+        SEQAN_ASSERT_EQ(target[1], TTraceSegment(1, 1, 1, TraceBitMap_<>::HORIZONTAL));
+        SEQAN_ASSERT_EQ(target[2], TTraceSegment(0, 0, 1, TraceBitMap_<>::DIAGONAL));
     }
 
 }
@@ -617,8 +608,7 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_right_affine_gaps)
         value(traceMatrix, 3, 2) = TraceBitMap_<>::VERTICAL_OPEN | TraceBitMap_<>::MAX_FROM_VERTICAL_MATRIX | TraceBitMap_<>::DIAGONAL;
 
 
-        TDPTraceNavigator navigator;
-        _init(navigator, traceMatrix, DPBandConfig<BandOff>());
+        TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOff>()};
 
         DnaString str0 = "AC";
         DnaString str1 = "CCC";
@@ -627,8 +617,8 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_right_affine_gaps)
         dpScout._maxHostPosition = 11;
         _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
 
-        SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 2, 1, +TraceBitMap_<>::VERTICAL));
-        SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 2, +TraceBitMap_<>::DIAGONAL));
+        SEQAN_ASSERT_EQ(target[0], TTraceSegment(2, 2, 1, TraceBitMap_<>::VERTICAL));
+        SEQAN_ASSERT_EQ(target[1], TTraceSegment(0, 0, 2, TraceBitMap_<>::DIAGONAL));
     }
 
     {   // Test inner gaps.
@@ -663,8 +653,7 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_right_affine_gaps)
         value(traceMatrix, 2, 4) = TraceBitMap_<>::NONE;
         value(traceMatrix, 3, 4) = TraceBitMap_<>::DIAGONAL;
 
-        TDPTraceNavigator navigator;
-        _init(navigator, traceMatrix, DPBandConfig<BandOff>());
+        TDPTraceNavigator navigator{traceMatrix, DPBandConfig<BandOff>()};
 
         DnaString str0 = "ACCA";
         DnaString str1 = "ACA";
@@ -674,9 +663,9 @@ SEQAN_DEFINE_TEST(test_align2_traceback_gaps_right_affine_gaps)
         _computeTraceback(target, navigator, dpScout, str0, str1, DPBandConfig<BandOff>(), TDPProfile());
 
         // TODO(rmaerker): This is disabled by default for the affine gap costs.
-        SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 2, 1, +TraceBitMap_<>::DIAGONAL));
-        SEQAN_ASSERT_EQ(target[1], TTraceSegment(2, 2, 1, +TraceBitMap_<>::HORIZONTAL));
-        SEQAN_ASSERT_EQ(target[2], TTraceSegment(0, 0, 2, +TraceBitMap_<>::DIAGONAL));
+        SEQAN_ASSERT_EQ(target[0], TTraceSegment(3, 2, 1, TraceBitMap_<>::DIAGONAL));
+        SEQAN_ASSERT_EQ(target[1], TTraceSegment(2, 2, 1, TraceBitMap_<>::HORIZONTAL));
+        SEQAN_ASSERT_EQ(target[2], TTraceSegment(0, 0, 2, TraceBitMap_<>::DIAGONAL));
     }
 }
 
