@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -96,8 +96,7 @@ SEQAN_DEFINE_TEST(test_arg_parse_ctd_support)
     ofstream.close();
 
     // compare ctd to expected
-    seqan::CharString goldPath = SEQAN_PATH_TO_ROOT();
-    append(goldPath, "/tests/arg_parse/test_app.ctd");
+    seqan::CharString goldPath = getAbsolutePath("/tests/arg_parse/test_app.ctd");
 
     SEQAN_ASSERT(seqan::_compareTextFilesAlt(toCString(outPath), toCString(goldPath)));
 }
