@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2015, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -179,7 +179,7 @@ _testBlastOutputGenerateContent(TFile & file,
 
             computeAlignmentStats(m, context);
             computeBitScore(m, context);
-            computeEValue(m, context);
+            computeEValue(m, records[q].qLength, context);
         }
     }
 
