@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // Copyright (c) 2013 NVIDIA Corporation
 // All rights reserved.
 //
@@ -122,9 +122,14 @@ typedef
     TagList<RankDictionary<Dna5,            Default3Level>,
     TagList<RankDictionary<Dna5Q,           Default3Level>,
     TagList<RankDictionary<ReducedMurphy10, Default3Level>,
+#ifndef __alpha__ // NOTE(h-2): fails on alpha for unknown reasons
     TagList<RankDictionary<AminoAcid,       Default3Level>,
+#endif
     RankDictionaryPrefixSumTypes
-    > > > > > > > > > > > > > > > > > > >
+    > > > > > > > > > > > > > > > > > >
+#ifndef __alpha__
+    >
+#endif
     RankDictionaryAllTypes;
 
 // ==========================================================================
