@@ -1,7 +1,7 @@
 // ==========================================================================
 //                 SeqAn - The Library for Sequence Analysis
 // ==========================================================================
-// Copyright (c) 2006-2016, Knut Reinert, FU Berlin
+// Copyright (c) 2006-2018, Knut Reinert, FU Berlin
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -628,7 +628,7 @@ void testStringPackedExtensionBitScanForward()
 
     {
         TBitString str;
-        SEQAN_ASSERT_EQ(bitScanForward(str), MaxValue<TPosition>::VALUE);
+        SEQAN_ASSERT_EQ(bitScanForward(str), std::numeric_limits<TPosition>::max());
     }
 }
 
@@ -662,7 +662,7 @@ void testStringPackedExtensionBitScanReverse()
 
     {
         TBitString str;
-        SEQAN_ASSERT_EQ(bitScanForward(str), MaxValue<TPosition>::VALUE);
+        SEQAN_ASSERT_EQ(bitScanForward(str), std::numeric_limits<TPosition>::max());
     }
 }
 
